% fig3.m
% 
% Generates a figure of ice volume as a function of time.  

clear all
close all

% Define some other parameters.  
d_row = 10; 
begin_row = (125* 10^ 3- 160)/ 20+ 1; 
paleo_tick = [-125 -115 -100 -75 -50 -25 -20 -5 0]; 
historic_tick = [1840 1900 2005 2100 2300 2500 2700 2900 3000 3100 3300 3500]; 
y_tick = [0: 2: 10]; 

% Read in the data tables.  Table 1 contains the ice volume as a function of 
% time; column 16 of table 2 contains information on whether each run's 
% simulated ice volume in 2005 AD is within 10% of the observed value.  
data = dlmread('data_table_1.csv'); 
end_row = numel(data(:, 1)); 
data2 = dlmread('data_table_2.csv'); 
yn = data2(2: 101, 16); 

% Plot the runs that *don't* meet the windowing criterion in gray.  
for i = 5: 1: 104; 
	subplot(2, 1, 1)
	if yn(i- 4, 1) ~= 1; 
		plot(data(1: d_row: end_row, 1)/ 10^ 3, data(1: d_row: end_row, i), 'color', [0.6 0.6 0.6]); 
	end
	hold on
	
	subplot(2, 1, 2)
	if yn(i- 4, 1) ~= 1; 
		plot(data(begin_row: end_row, 1)+ 2000, data(begin_row: end_row, i), 'color', [0.6 0.6 0.6]); 
	end
	hold on
end

% Plot the runs that *do* meet the windowing criterion in blue.  
for i = 5: 1: 104; 
	subplot(2, 1, 1)
	if yn(i- 4, 1) == 1; 
		plot(data(1: d_row: end_row, 1)/ 10^ 3, data(1: d_row: end_row, i), 'color', [0 0 1]); 
	end
	
	subplot(2, 1, 2)
	if yn(i- 4, 1) == 1; 
		plot(data(begin_row: end_row, 1)+ 2000, data(begin_row: end_row, i), 'color', [0 0 1]); 
	end
end

% Plot Ralf's results on top in red and make the plots look nice.  
subplot(2, 1, 1)
plot(data(1: d_row: end_row, 1)/ 10^ 3, data(1: d_row: end_row, 4), 'color', [1 0 0]); 
axis([-125 1.5 -1 11])
set(gca, 'xtick', paleo_tick)
set(gca, 'ytick', y_tick)
xlabel('Time (ka relative to 2000 AD)')
ylabel('Ice volume (m sle)')
% plot([-0.160 -0.160], get(gca, 'ylim'))

subplot(2, 1, 2)
plot(data(begin_row: end_row, 1)+ 2000, data(begin_row: end_row, 4), 'color', [1 0 0]); 
axis([1840 3500 -1 11])
set(gca, 'xtick', historic_tick)
set(gca, 'ytick', y_tick)
xlabel('Time (years AD)')
ylabel('Ice volume (m sle)')
plot([2005 2005], get(gca, 'ylim'), 'color', [0 0 0])